==> esb-deployer-v0.1-sources.jar: com/ebmwebsourcing/seacloud/deployer/ESBDeployerModule.java <==
package com.ebmwebsourcing.seacloud.deployer;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.List;

import javax.xml.namespace.QName;

import seacloud.petalslink.com.service.management.cloud._1_0.CloudManagementException;

import com.ebmwebsourcing.esstar.management.UserManagementClient;
import com.ebmwebsourcing.seacloud.model.AbstractModule;
import com.ebmwebsourcing.seacloud.model.AdvancedESBModule;
import com.ebmwebsourcing.seacloud.model.DeployerModule;

import easybox.esstar.petalslink.com.management.model.datatype._1.EJaxbDeploy;
import easybox.esstar.petalslink.com.management.model.datatype._1.EJaxbDeployResponse;
import easybox.esstar.petalslink.com.management.model.datatype._1.EJaxbDeployementReport;
import esstar.petalslink.com.data.management.user._1.Bind;
import esstar.petalslink.com.data.management.user._1.BindResponse;
import esstar.petalslink.com.data.management.user._1.Proxify;
import esstar.petalslink.com.data.management.user._1.ProxifyResponse;
import esstar.petalslink.com.service.management._1_0.ManagementException;

public class ESBDeployerModule extends AbstractModule implements DeployerModule, AdvancedESBModule {

	private UserManagementClient client = null;

	public ESBDeployerModule(List<URL> adminAdresses) throws CloudManagementException {
		super(adminAdresses);

		if(this.externalComponentAdresses.size() > 0) {
			this.client = new UserManagementClient(this.externalComponentAdresses.get(0).toString());
		}
	}

	/**
	 * @return the clientProxy
	 */
	private synchronized UserManagementClient getClientProxy() {
		return this.client;
	}

	@Override
	public EJaxbDeployResponse deploy(EJaxbDeploy parameters)
			throws CloudManagementException {
		try {
			System.out.println("--------- DEPLOY");
			System.out.println("--------- DEPLOY BPEL: " + parameters.getMainResource().getFileURI());
			EJaxbDeployementReport report = this.getClientProxy().deploy(new URL(parameters.getMainResource().getFileURI()));
			EJaxbDeployResponse resp = new EJaxbDeployResponse();
			resp.setDeployementReport(report);
			return resp;
		} catch (ManagementException e) {
			throw new CloudManagementException(e.getMessage(), e);
		} catch (MalformedURLException e) {
			throw new CloudManagementException(e.getMessage(), e);
		}
	}

	@Override
	public BindResponse bind(Bind parameters) throws CloudManagementException {
		try {
			return this.getClientProxy().bind(parameters);
		} catch (ManagementException e) {
			throw new CloudManagementException(e.getMessage(), e);
		}
	}

	@Override
	public String expose(QName serviceName, String endpointName)
			throws CloudManagementException {
		try {
			return this.getClientProxy().expose(serviceName, endpointName);
		} catch (ManagementException e) {
			throw new CloudManagementException(e.getMessage(), e);
		}
	}

	@Override
	public ProxifyResponse proxify(Proxify parameters)
			throws CloudManagementException {
		try {
			return this.getClientProxy().proxify(parameters);
		} catch (ManagementException e) {
			throw new CloudManagementException(e.getMessage(), e);
		}
	}

}

==> esb-deployer-v0.4-sources.jar: com/ebmwebsourcing/seacloud/deployer/ESBDeployerModule.java <==
package com.ebmwebsourcing.seacloud.deployer;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.List;

import javax.xml.namespace.QName;

import seacloud.petalslink.com.service.management.cloud._1_0.CloudManagementException;

import com.ebmwebsourcing.esstar.management.UserManagementClient;
import com.ebmwebsourcing.seacloud.model.AbstractModule;
import com.ebmwebsourcing.seacloud.model.AdvancedESBModule;
import com.ebmwebsourcing.seacloud.model.DeployerModule;

import easybox.esstar.petalslink.com.management.model.datatype._1.EJaxbDeploy;
import easybox.esstar.petalslink.com.management.model.datatype._1.EJaxbDeployResponse;
import easybox.esstar.petalslink.com.management.model.datatype._1.EJaxbDeployementReport;
import esstar.petalslink.com.data.management.user._1.Bind;
import esstar.petalslink.com.data.management.user._1.BindResponse;
import esstar.petalslink.com.data.management.user._1.Proxify;
import esstar.petalslink.com.data.management.user._1.ProxifyResponse;
import esstar.petalslink.com.service.management._1_0.ManagementException;

public class ESBDeployerModule extends AbstractModule implements DeployerModule, AdvancedESBModule {

	private UserManagementClient client = null;

	public ESBDeployerModule(List<URL> adminAdresses) throws CloudManagementException {
		super(adminAdresses);

		if(this.externalComponentAdresses.size() > 0) {
			this.client = new UserManagementClient(this.externalComponentAdresses.get(0).toString());
		}
	}

	/**
	 * @return the clientProxy
	 */
	private synchronized UserManagementClient getClientProxy() {
		return this.client;
	}

	@Override
	public EJaxbDeployResponse deploy(EJaxbDeploy parameters)
			throws CloudManagementException {
		try {
			System.out.println("--------- DEPLOY");
			System.out.println("--------- DEPLOY BPEL: " + parameters.getMainResource().getFileURI());
			
			// TODO: EasyESB does not support deploy with document in attachment (only from url)
			parameters.getMainResource().setAttachment(null);
			EJaxbDeployResponse report = this.getClientProxy().deploy(parameters);
			return report;
		} catch (ManagementException e) {
			throw new CloudManagementException(e.getMessage(), e);
		} 
	}

	@Override
	public BindResponse bind(Bind parameters) throws CloudManagementException {
		try {
			return this.getClientProxy().bind(parameters);
		} catch (ManagementException e) {
			throw new CloudManagementException(e.getMessage(), e);
		}
	}

	@Override
	public String expose(QName serviceName, String endpointName)
			throws CloudManagementException {
		try {
			return this.getClientProxy().expose(serviceName, endpointName);
		} catch (ManagementException e) {
			throw new CloudManagementException(e.getMessage(), e);
		}
	}

	@Override
	public ProxifyResponse proxify(Proxify parameters)
			throws CloudManagementException {
		try {
			return this.getClientProxy().proxify(parameters);
		} catch (ManagementException e) {
			throw new CloudManagementException(e.getMessage(), e);
		}
	}

}
